@@ -25,12 +25,19 @@ agent = Agent(
 ```
 """
 
+from __future__ import annotations
+
 from typing import Self
-from agentle.generations.models.generation.generation_config import GenerationConfig
+
 from rsb.models.base_model import BaseModel
 from rsb.models.field import Field
 from rsb.models.model_validator import model_validator
 
+from agentle.generations.models.generation.generation_config import GenerationConfig
+from agentle.generations.models.generation.generation_config_dict import (
+    GenerationConfigDict,
+)
+
 
 class AgentConfig(BaseModel):
     """
@@ -65,7 +72,9 @@ class AgentConfig(BaseModel):
         generations per request are not supported for agents.
     """
 
-    generationConfig: GenerationConfig = Field(default_factory=GenerationConfig)
+    generationConfig: GenerationConfig | GenerationConfigDict = Field(
+        default_factory=GenerationConfig
+    )
     """Configuration for the language model generation process."""
 
     maxToolCalls: int = Field(default=15)
@@ -74,6 +83,24 @@ class AgentConfig(BaseModel):
     maxIterations: int = Field(default=10)
     """Maximum number of agent reasoning iterations before terminating."""
 
+    def clone(
+        self,
+        new_generation_config: GenerationConfig | GenerationConfigDict | None = None,
+        new_max_tool_calls: int | None = None,
+        new_max_iterations: int | None = None,
+    ) -> AgentConfig:
+        return AgentConfig(
+            generationConfig=new_generation_config or self.generationConfig,
+            maxToolCalls=new_max_tool_calls or self.maxToolCalls,
+            maxIterations=new_max_iterations or self.maxIterations,
+        )
+
+    @property
+    def generation_config(self) -> GenerationConfig:
+        if isinstance(self.generationConfig, dict):
+            return GenerationConfig.model_validate(self.generationConfig)
+        return self.generationConfig
+
     @model_validator(mode="after")
     def validate_max_tool_calls(self) -> Self:
         """
@@ -88,7 +115,7 @@ class AgentConfig(BaseModel):
         Raises:
             ValueError: If generationConfig.n is greater than 1.
         """
-        if self.generationConfig.n > 1:
+        if self.generation_config.n > 1:
             raise ValueError(
                 "a number of choices > 1 is not supported for agents. This is NOT planned to be supported."
                 + "If you want multiple choices/responses, just call the agent n times."
