@@ -19,7 +19,7 @@ API requirements, while maintaining the common interface for framework consumers
 from __future__ import annotations
 
 import abc
-from collections.abc import Sequence
+from collections.abc import MutableSequence, Sequence
 from typing import TYPE_CHECKING, Any, Never, cast
 
 from rsb.containers.maybe import Maybe
@@ -112,11 +112,11 @@ class GenerationProvider(abc.ABC):
         """
         ...
 
-    def create_generation_by_prompt[T = WithoutStructuredOutput](
+    def generate_by_prompt[T = WithoutStructuredOutput](
         self,
+        prompt: str | Prompt | Part | Sequence[Part],
         *,
         model: str | ModelKind | None = None,
-        prompt: str | Prompt | Part | Sequence[Part],
         developer_prompt: str | Prompt | None = None,
         response_schema: type[T] | None = None,
         generation_config: GenerationConfig | GenerationConfigDict | None = None,
@@ -143,7 +143,7 @@ class GenerationProvider(abc.ABC):
         _generation_config = self._normalize_generation_config(generation_config)
 
         return run_sync(
-            self.create_generation_by_prompt_async,
+            self.generate_by_prompt_async,
             timeout=_generation_config.timeout
             if _generation_config.timeout
             else _generation_config.timeout_s * 1000
@@ -159,11 +159,11 @@ class GenerationProvider(abc.ABC):
             tools=tools,
         )
 
-    async def create_generation_by_prompt_async[T = WithoutStructuredOutput](
+    async def generate_by_prompt_async[T = WithoutStructuredOutput](
         self,
+        prompt: str | Prompt | Part | Sequence[Part],
         *,
         model: str | ModelKind | None = None,
-        prompt: str | Prompt | Part | Sequence[Part],
         developer_prompt: str | Prompt | None = None,
         response_schema: type[T] | None = None,
         generation_config: GenerationConfig | GenerationConfigDict | None = None,
@@ -173,7 +173,7 @@ class GenerationProvider(abc.ABC):
         Create a generation from a prompt asynchronously.
 
         This method converts various prompt formats into a structured message sequence
-        and calls the create_generation_async method with the converted messages.
+        and calls the generate_async method with the converted messages.
 
         Args:
             model: The model identifier to use for generation.
@@ -216,7 +216,7 @@ class GenerationProvider(abc.ABC):
             parts=cast(Sequence[TextPart], developer_message_parts)
         )
 
-        return await self.create_generation_async(
+        return await self.generate_async(
             model=model,
             messages=[developer_message, user_message],
             response_schema=response_schema,
@@ -224,7 +224,7 @@ class GenerationProvider(abc.ABC):
             tools=tools,
         )
 
-    def create_generation[T = WithoutStructuredOutput](
+    def generate[T = WithoutStructuredOutput](
         self,
         *,
         model: str | ModelKind | None = None,
@@ -253,7 +253,7 @@ class GenerationProvider(abc.ABC):
         _generation_config = self._normalize_generation_config(generation_config)
 
         return run_sync(
-            self.create_generation_async,
+            self.generate_async,
             timeout=_generation_config.timeout
             if _generation_config.timeout
             else _generation_config.timeout_s * 1000
@@ -269,7 +269,7 @@ class GenerationProvider(abc.ABC):
         )
 
     @abc.abstractmethod
-    async def create_generation_async[T = WithoutStructuredOutput](
+    async def generate_async[T = WithoutStructuredOutput](
         self,
         *,
         model: str | ModelKind | None = None,
@@ -347,6 +347,33 @@ class GenerationProvider(abc.ABC):
         """
         ...
 
+    def _resolve_model(self, model: str | ModelKind | None) -> str:
+        if model and model in [
+            "category_nano",
+            "category_mini",
+            "category_standard",
+            "category_pro",
+            "category_flagship",
+            "category_reasoning",
+            "category_vision",
+            "category_coding",
+            "category_instruct",
+            "category_nano_experimental",
+            "category_mini_experimental",
+            "category_standard_experimental",
+            "category_pro_experimental",
+            "category_flagship_experimental",
+            "category_reasoning_experimental",
+            "category_vision_experimental",
+            "category_coding_experimental",
+            "category_instruct_experimental",
+        ]:
+            return self.map_model_kind_to_provider_model(
+                model_kind=cast(ModelKind, model)
+            )
+
+        return model or self.default_model
+
     def _normalize_generation_config(
         self, generation_config: GenerationConfig | GenerationConfigDict | None
     ) -> GenerationConfig:
@@ -362,13 +389,22 @@ class GenerationProvider(abc.ABC):
             f"Model kind {model_kind} is not supported by {self.__class__.__name__}"
         )
 
-    def __add__(self, other: GenerationProvider) -> FailoverGenerationProvider:
+    def __add__(
+        self, other: GenerationProvider | Sequence[GenerationProvider]
+    ) -> FailoverGenerationProvider:
         from agentle.generations.providers.failover.failover_generation_provider import (
             FailoverGenerationProvider,
         )
 
+        match other:
+            case GenerationProvider():
+                providers: MutableSequence[GenerationProvider] = [self, other]
+            case _:
+                providers = [self] + list(other)
+
         return FailoverGenerationProvider(
-            generation_providers=[self, other],
-            tracing_client=self.tracing_client.unwrap()
-            or other.tracing_client.unwrap(),
+            generation_providers=providers,
+            tracing_client=self.tracing_client.unwrap() or other.tracing_client.unwrap()
+            if isinstance(other, GenerationProvider)
+            else other[0].tracing_client.unwrap(),
         )
