@@ -1,5 +1,5 @@
 from textwrap import dedent
-from typing import Any
+from typing import Any, Literal
 
 from rsb.models.base_model import BaseModel
 from rsb.models.field import Field
@@ -17,6 +17,11 @@ class ToolExecutionResult(BaseModel):
     that was returned, providing a complete record of the tool interaction.
     """
 
+    type: Literal["tool_execution_result"] = Field(
+        default="tool_execution_result",
+        description="Discriminator field to identify this as a tool execution suggestion.",
+    )
+
     suggestion: ToolExecutionSuggestion
     """The tool execution suggestion that was executed."""
 
@@ -32,6 +37,10 @@ class ToolExecutionResult(BaseModel):
     error_message: str | None = Field(default=None)
     """Error message if the tool execution failed."""
 
+    @property
+    def text(self) -> str:
+        return str(self)
+
     def __str__(self) -> str:
         return dedent(f"""\
         <sugestion>
