@@ -56,14 +56,14 @@ def audio_description_agent_default_factory(
     from agentle.generations.models.structured_outputs_store.audio_description import (
         AudioDescription,
     )
-    from agentle.generations.providers.google.google_genai_generation_provider import (
-        GoogleGenaiGenerationProvider,
+    from agentle.generations.providers.google.google_generation_provider import (
+        GoogleGenerationProvider,
     )
 
     agent = Agent(
         model="gemini-2.0-flash",
         instructions="You are a helpful assistant that deeply understands audio files.",
-        generation_provider=provider or GoogleGenaiGenerationProvider(),
+        generation_provider=provider or GoogleGenerationProvider(),
         response_schema=AudioDescription,
     )
 
