@@ -5,13 +5,23 @@ This example demonstrates how to create an agent that returns structured data
 using a Pydantic model as a response schema.
 """
 
+from typing import Optional
+
+from dotenv import load_dotenv
 from pydantic import BaseModel
-from typing import List, Optional
 
 from agentle.agents.agent import Agent
-from agentle.generations.providers.google.google_genai_generation_provider import (
-    GoogleGenaiGenerationProvider,
+from agentle.agents.agent_config import AgentConfig
+from agentle.generations.models.generation.generation_config import GenerationConfig
+from agentle.generations.models.generation.trace_params import TraceParams
+from agentle.generations.providers.cerebras.cerebras_generation_provider import (
+    CerebrasGenerationProvider,
 )
+from agentle.generations.tracing.langfuse import LangfuseObservabilityClient
+
+load_dotenv()
+
+tracing_client = LangfuseObservabilityClient()
 
 
 # Define a structured response schema using Pydantic
@@ -19,21 +29,29 @@ class WeatherForecast(BaseModel):
     location: str
     current_temperature: float
     conditions: str
-    forecast: List[str]
+    forecast: list[str]
     humidity: Optional[int] = None
 
 
 # Create an agent with the response schema
 structured_agent = Agent(
     name="Weather Agent",
-    generation_provider=GoogleGenaiGenerationProvider(),
-    model="gemini-2.0-flash",
+    generation_provider=CerebrasGenerationProvider(),
+    model="category_standard_experimental",
     instructions="You are a weather forecasting assistant. When asked about weather, provide accurate forecasts.",
     response_schema=WeatherForecast,  # This defines the expected response structure
+    config=AgentConfig(
+        generationConfig=GenerationConfig(
+            trace_params=TraceParams(
+                name="Weather App",
+                user_id="test_user",
+            )
+        )
+    ),
 )
 
 # Run the agent with a query that requires structured data
-response = structured_agent.run("What's the weather like in San Francisco?")
+response = structured_agent.run("Qual vai ser o clima em uberaba hoje?")
 
 
 weather = response.parsed
